@@ -332,9 +332,9 @@ class Database(object):
     def _get(self, id, d, rev=None):
 
         if rev:
-            response = yield self.request('GET', path=id, rev=rev)
+            response = yield self.request('GET', path=self._encodeID(id), rev=rev)
         else:
-            response = yield self.request('GET', path=id, conflicts=True)
+            response = yield self.request('GET', path=self._encodeID(id), conflicts=True)
 
         if '_id' not in response or 'error' in response:
             response = None
